@@ -1,21 +1,22 @@
 MixNRMI2 <-
 function (x, probs = c(0.025, 0.5, 0.975), Alpha = 1, Beta = 0, 
-    Gama = 0.4, distr.k = 1, distr.py0 = 1, mu.py0 = mean(x), 
-    sigma.py0 = 1.5 * sd(x), distr.pz0 = 2, mu.pz0 = 1, sigma.pz0 = 10, 
-    delta = 3, Delta = 2, Nm = 50, Nx = 100, Nit = 1000, Pbi = 0.1, 
-    epsilon = NULL, printtime = TRUE) 
+    Gama = 0.4, distr.k = 1, distr.py0 = 1, distr.pz0 = 2, mu.pz0 = 3, 
+    sigma.pz0 = sqrt(10), delta = 4, kappa = 2, Delta = 2, Nm = 50, 
+    Nx = 100, Nit = 1000, Pbi = 0.1, epsilon = NULL, printtime = TRUE) 
 {
     if (is.null(distr.k)) 
         stop("Argument distr.k is NULL. Should be provided. See help for details.")
     if (is.null(distr.py0)) 
         stop("Argument distr.py0 is NULL. Should be provided. See help for details.")
-    if (is.null(mu.py0)) 
-        stop("Argument mu.py0 is NULL. Should be provided. See help for details.")
-    if (is.null(sigma.py0)) 
-        stop("Argument sigma.py0 is NULL. Should be provided. See help for details.")
-    tCurr <- tInit <- proc.time()
+    tInit <- proc.time()
     n <- length(x)
     y <- x
+    for (i in 1:(n/2)) {
+        y[i] <- mean(x[1:(n/2)])
+    }
+    for (i in (n/2):n) {
+        y[i] <- mean(x[(n/2):n])
+    }
     z <- rep(1, n)
     u <- 1
     if (is.null(epsilon)) 
@@ -25,6 +26,8 @@ function (x, probs = c(0.025, 0.5, 0.975), Alpha = 1, Beta = 0,
     fx <- matrix(NA, nrow = n, ncol = Nit)
     R <- seq(Nit)
     U <- seq(Nit)
+    mu.py0 = mean(x)
+    sigma.py0 = sd(x)
     for (j in seq(Nit)) {
         if (floor(j/100) == ceiling(j/100)) 
             cat("MCMC iteration", j, "of", Nit, "\n")
@@ -43,11 +46,14 @@ function (x, probs = c(0.025, 0.5, 0.975), Alpha = 1, Beta = 0,
         TauyC <- rk(Nm, distr = distr.py0, mu = mu.py0, sigma = sigma.py0)
         TauzC <- rk(Nm, distr = distr.pz0, mu = mu.pz0, sigma = sigma.pz0)
         tt <- gsYZstar(ystar, zstar, nstar, rstar, idx, x, delta, 
-            distr.k = distr.k, distr.py0 = distr.py0, mu.py0 = mu.py0, 
-            sigma.py0 = sigma.py0, distr.pz0 = distr.pz0, mu.pz0 = mu.pz0, 
-            sigma.pz0 = sigma.pz0)
+            kappa, distr.k = distr.k, distr.py0 = distr.py0, 
+            mu.py0 = mu.py0, sigma.py0 = sigma.py0, distr.pz0 = distr.pz0, 
+            mu.pz0 = mu.pz0, sigma.pz0 = sigma.pz0)
         ystar <- tt$ystar
         zstar <- tt$zstar
+        tt <- gsHP(ystar, rstar, distr.py0)
+        mu.py0 <- tt$mu.py0
+        sigma.py0 <- tt$sigma.py0
         Jstar <- rgamma(rstar, nstar - Gama, Beta + u)
         Tauy <- c(TauyC, ystar)
         Tauz <- c(TauzC, zstar)
